##
# Physical Constants
::: fdtdx.constants.c
::: fdtdx.constants.mu0
::: fdtdx.constants.eps0
::: fdtdx.constants.eta0
::: fdtdx.constants.wavelength_to_period

# Material Properties
::: fdtdx.constants.relative_permittivity_air
::: fdtdx.constants.relative_permittivity_substrate
::: fdtdx.constants.relative_permittivity_polymer
::: fdtdx.constants.relative_permittivity_silicon
::: fdtdx.constants.relative_permittivity_silica
::: fdtdx.constants.relative_permittivity_SZ_2080
::: fdtdx.constants.relative_permittivity_ma_N_1400_series
::: fdtdx.constants.relative_permittivity_bacteria
::: fdtdx.constants.relative_permittivity_water
::: fdtdx.constants.relative_permittivity_fused_silica
::: fdtdx.constants.relative_permittivity_coated_silica
::: fdtdx.constants.relative_permittivity_resin
::: fdtdx.constants.relative_permittivity_ormo_prime
